summaryrefslogtreecommitdiffstats
path: root/ash/host/root_window_host_factory.cc
diff options
context:
space:
mode:
Diffstat (limited to 'ash/host/root_window_host_factory.cc')
-rw-r--r--ash/host/root_window_host_factory.cc14
1 files changed, 7 insertions, 7 deletions
diff --git a/ash/host/root_window_host_factory.cc b/ash/host/root_window_host_factory.cc
index 1f4cb3d..27bb614 100644
--- a/ash/host/root_window_host_factory.cc
+++ b/ash/host/root_window_host_factory.cc
@@ -8,14 +8,14 @@
namespace {
-class RootWindowHostFactoryImpl : public ash::RootWindowHostFactory {
+class WindowTreeHostFactoryImpl : public ash::WindowTreeHostFactory {
public:
- RootWindowHostFactoryImpl() {}
+ WindowTreeHostFactoryImpl() {}
- // Overridden from RootWindowHostFactory:
- virtual aura::RootWindowHost* CreateRootWindowHost(
+ // Overridden from WindowTreeHostFactory:
+ virtual aura::WindowTreeHost* CreateWindowTreeHost(
const gfx::Rect& initial_bounds) OVERRIDE {
- return aura::RootWindowHost::Create(initial_bounds);
+ return aura::WindowTreeHost::Create(initial_bounds);
}
};
@@ -24,8 +24,8 @@ class RootWindowHostFactoryImpl : public ash::RootWindowHostFactory {
namespace ash {
// static
-RootWindowHostFactory* RootWindowHostFactory::Create() {
- return new RootWindowHostFactoryImpl;
+WindowTreeHostFactory* WindowTreeHostFactory::Create() {
+ return new WindowTreeHostFactoryImpl;
}
} // namespace ash